@@ -1,4 +1,4 @@
-from .._find import _find as find 
+'''from .._find import _find as find 
 
 
 from .._find import _find_func, \
@@ -8,7 +8,8 @@ from .._find import _find_func, \
                    _check_func,\
                    _get_dirs_prune,\
                    _get_dirs_total,\
-                   _fcall,get_face_path 
+                   _fcall,get_face_path
+'''                   
            
            
            
