@@ -16,7 +16,10 @@ from moofei._find import _py
 import time
 import zipfile 
 
-from plugin_box_zip import Plugin_Box_Zip as Plugin_Box_Jar
+try:
+    from .plugin_box_zip import Plugin_Box_Zip as Plugin_Box_Jar
+except ModuleNotFoundError:
+    from moofei.find.plugin_box_zip import Plugin_Box_Zip as Plugin_Box_Jar
 
 
        
